==> haskell-parsers-0.12.5-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.5
id: parsers-0.12.5-gRlEiIhhgLKOqpTXe9HD9
key: parsers-0.12.5-gRlEiIhhgLKOqpTXe9HD9
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.LookAhead
    Text.Parser.Permutation Text.Parser.Expression Text.Parser.Token
    Text.Parser.Token.Style Text.Parser.Token.Highlight
abi: 32b00db47623488d941cb30b153614ec
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/parsers-0.12.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/parsers-0.12.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/parsers-0.12.5
hs-libraries: HSparsers-0.12.5-gRlEiIhhgLKOqpTXe9HD9
depends:
    attoparsec-0.13.1.0-oc29svN3SiFq1TojBIbwV base-4.9.0.0
    base-orphans-0.6-5PayU02PR2MEqN5xZtCkua
    charset-0.3.7.1-K8TwicOajUdHmq8r06VVim containers-0.5.7.1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
    scientific-0.3.4.15-GEIRVwGBHHyElVCNt38fm3
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.5-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.5
id: parsers-0.12.5-6VUrmFpeF5oHKYq1qKXQZ
key: parsers-0.12.5-6VUrmFpeF5oHKYq1qKXQZ
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.LookAhead
    Text.Parser.Permutation Text.Parser.Expression Text.Parser.Token
    Text.Parser.Token.Style Text.Parser.Token.Highlight
abi: 953aca246701e7b39152fd1468dc38f6
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/parsers-0.12.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/parsers-0.12.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/parsers-0.12.5
hs-libraries: HSparsers-0.12.5-6VUrmFpeF5oHKYq1qKXQZ
depends:
    attoparsec-0.13.1.0-ETec0FJZJHgARrgZXhaej9 base-4.9.1.0
    base-orphans-0.6-AbJ3lKVXygDCG0eeQEv8Iu
    charset-0.3.7.1-ExxkLwSUKUPEceMD96Skef containers-0.5.7.1
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
    scientific-0.3.4.15-Is44CvKqXBF5ugVqyS94hI
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
